#[non_exhaustive]pub enum AccountType {
Asset,
Liability,
Equity,
Revenue,
Expense,
}Expand description
GL Account type (follows standard accounting)
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Asset
Cash, receivables, inventory, and other economic resources.
Liability
Obligations owed to creditors and suppliers.
Equity
Owner’s residual interest in the business.
Revenue
Income earned from sales or services.
Expense
Costs incurred in earning revenue.
Implementations
Sourceimpl AccountType
impl AccountType
Sourcepub const fn normal_balance(&self) -> BalanceSide
pub const fn normal_balance(&self) -> BalanceSide
Returns the normal balance side for this account type
Sourcepub const fn is_balance_sheet(&self) -> bool
pub const fn is_balance_sheet(&self) -> bool
Returns true if this account type appears on the Balance Sheet
Sourcepub const fn is_income_statement(&self) -> bool
pub const fn is_income_statement(&self) -> bool
Returns true if this account type appears on the Income Statement