#[non_exhaustive]pub enum CollectionActivityType {
DunningLetterSent,
PhoneCall,
Email,
InPersonVisit,
PromiseToPay,
PaymentPlanCreated,
SentToCollections,
WriteOffApproved,
DisputeLogged,
DisputeResolved,
Note,
}Expand description
Collection activity type
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DunningLetterSent
A dunning letter was sent to the customer.
PhoneCall
A phone call was made to the customer.
An email was sent to the customer.
InPersonVisit
A representative visited the customer in person.
PromiseToPay
Customer provided a verbal or written commitment to pay by a date.
PaymentPlanCreated
An installment payment plan was established with the customer.
SentToCollections
Account was referred to an internal or external collections team.
WriteOffApproved
Write-off was reviewed and approved.
DisputeLogged
A formal dispute was opened by the customer.
DisputeResolved
A customer dispute was resolved.
Note
General free-text note recorded on the account.