#[non_exhaustive]pub enum CostAdjustmentType {
StandardCostUpdate,
Revaluation,
WriteOff,
Correction,
}Expand description
Cost adjustment type.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
StandardCostUpdate
Periodic update to the standard cost for a SKU.
Revaluation
Restate inventory value to reflect current market or replacement cost.
WriteOff
Remove obsolete or damaged inventory value from the books.
Correction
Fix a data entry or calculation error in recorded cost.