#[non_exhaustive]pub enum CreditMemoStatus {
Open,
PartiallyApplied,
FullyApplied,
Voided,
}Expand description
Credit memo status
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Open
Credit memo is available and has not been applied.
PartiallyApplied
A portion of the credit has been applied to one or more invoices.
FullyApplied
The entire credit amount has been applied and the memo is exhausted.
Voided
Credit memo has been cancelled and cannot be applied.