#[non_exhaustive]pub enum Disposition {
UseAsIs,
Rework,
Repair,
Scrap,
ReturnToVendor,
Downgrade,
SortAndScreen,
}Expand description
Disposition decision for non-conforming material
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UseAsIs
Material is accepted in its current state without modification.
Rework
Material will be re-processed to meet the original specification.
Repair
Material will be fixed to an acceptable but possibly different specification.
Scrap
Material is disposed of; cannot be used or sold.
ReturnToVendor
Material is returned to the supplier for credit or replacement.
Downgrade
Material is reclassified to a lower-grade specification.
SortAndScreen
Each unit is individually inspected to separate conforming from non-conforming.