#[non_exhaustive]pub enum HoldType {
QualityInspection,
CustomerReturn,
Recall,
Damaged,
Expired,
Quarantine,
RegulatoryHold,
InvestigationHold,
}Expand description
Type of quality hold
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
QualityInspection
Held pending a quality inspection decision.
CustomerReturn
Returned by a customer; awaiting disposition.
Recall
Subject to a product recall.
Damaged
Goods were damaged and cannot be sold as-is.
Expired
Goods have passed or are approaching their expiry date.
Quarantine
Isolated to prevent potential contamination or spread.
RegulatoryHold
Held due to a regulatory agency requirement or investigation.
InvestigationHold
Held while an internal investigation is in progress.