#[non_exhaustive]pub enum PackStatus {
Pending,
Assigned,
ReadyToPack,
InProgress,
Completed,
Cancelled,
}Expand description
Status of a pack task.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Pending
Pack task created; picking for this order is not yet complete.
Assigned
Pack task has been assigned to a packing station or worker.
ReadyToPack
All picks for the order are complete; packing can begin.
InProgress
Worker is actively packing items into cartons.
Completed
All items have been packed and cartons are sealed.
Cancelled
Pack task was cancelled; cartons were not produced.