#[non_exhaustive]pub enum PaymentStatusAP {
Pending,
Processed,
Cleared,
Voided,
Failed,
}Expand description
AP payment status.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Pending
Payment has been created but not yet submitted to the bank.
Processed
Payment has been submitted to the bank for processing.
Cleared
Bank has confirmed the funds have been debited.
Voided
Payment was cancelled before or after submission.
Failed
Payment was rejected or returned by the bank.