PaymentTransactionStatus

Enum PaymentTransactionStatus 

#[non_exhaustive]
pub enum PaymentTransactionStatus { Pending, Processing, RequiresAction, Completed, Failed, Cancelled, Refunded, PartiallyRefunded, Disputed, }
Payment transaction status in the processing lifecycle

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Pending

Payment is pending processing



Processing

Payment is being processed



RequiresAction

Payment requires additional action (e.g., 3D Secure)



Completed

Payment was successfully completed



Failed

Payment failed



Cancelled

Payment was cancelled



Refunded

Payment was refunded (fully)



PartiallyRefunded

Payment was partially refunded



Disputed

Payment is disputed/chargeback

Implementations

Source

impl PaymentTransactionStatus

pub fn can_transition_to(self, next: PaymentTransactionStatus) -> bool

Check if a status transition is allowed.

pub const fn is_terminal(self) -> bool

Returns true if this status is a terminal state.

pub const fn is_successful(self) -> bool

Returns true if this status represents a successful payment.

pub const fn is_in_progress(self) -> bool

Returns true if this payment is still in progress.

pub const fn is_refundable(self) -> bool

Returns true if a payment in this status may be refunded.

Only successfully captured funds can be refunded: a Completed payment, or one that is already PartiallyRefunded (so the remaining balance can be returned). Pending, Processing, RequiresAction, Failed, Cancelled, Disputed, and fully Refunded payments are not refundable.