#[non_exhaustive]pub enum PickStatus {
Pending,
Assigned,
InProgress,
Completed,
Short,
Cancelled,
}Expand description
Status of a pick task.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Pending
Pick task has been created but not yet assigned to a worker.
Assigned
Pick task has been assigned to a worker but not yet started.
InProgress
Worker is actively picking the item.
Completed
All requested quantity has been picked.
Short
Requested quantity was not available in the source location.
Cancelled
Pick task was cancelled; item will not be picked.