#[non_exhaustive]pub enum RefundStatus {
Pending,
Processing,
Completed,
Failed,
Cancelled,
}Expand description
Refund status
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Pending
Refund is pending
Processing
Refund is being processed
Completed
Refund completed successfully
Failed
Refund failed
Cancelled
Refund was cancelled
Implementations
Sourceimpl RefundStatus
impl RefundStatus
Sourcepub fn can_transition_to(self, next: RefundStatus) -> bool
pub fn can_transition_to(self, next: RefundStatus) -> bool
Check if a status transition is allowed.
Sourcepub const fn is_in_progress(self) -> bool
pub const fn is_in_progress(self) -> bool
Returns true if this refund is still in progress.
Sourcepub const fn is_terminal(self) -> bool
pub const fn is_terminal(self) -> bool
Returns true if this status is a terminal state.