#[non_exhaustive]pub enum Severity {
Critical,
Major,
Minor,
Observation,
}Expand description
Severity level
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Critical
Defect poses an immediate safety or compliance risk; requires urgent action.
Major
Significant defect likely to affect product function or customer satisfaction.
Minor
Small defect with limited impact on product use or appearance.
Observation
Noteworthy finding that does not rise to the level of a defect.