#[non_exhaustive]pub enum TrustLevel {
Sandbox,
Standard,
Verified,
Enterprise,
}Expand description
Trust level for agent cards
Higher trust levels enable higher transaction limits and more capabilities.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Sandbox
Sandbox - for testing only, no real transactions
Standard
Standard - default level for new agents
Verified
Verified - identity verified, higher limits
Enterprise
Enterprise - business verified, highest limits
Implementations
Sourceimpl TrustLevel
impl TrustLevel
Sourcepub const fn default_transaction_limit(&self) -> u64
pub const fn default_transaction_limit(&self) -> u64
Get the default transaction limit for this trust level (in USDC cents)
Sourcepub const fn default_daily_limit(&self) -> u64
pub const fn default_daily_limit(&self) -> u64
Get the default daily volume limit for this trust level