#[non_exhaustive]pub enum VarianceType {
Purchase,
Material,
Labor,
Overhead,
Efficiency,
Volume,
}Expand description
Variance type.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Purchase
Difference between purchase price and standard cost.
Material
Difference in raw material usage versus the standard bill of materials.
Labor
Difference in direct labor hours or rates versus standard.
Overhead
Difference in applied overhead versus actual overhead incurred.
Efficiency
Difference due to operating at a different efficiency than standard.
Volume
Difference due to producing a different volume than the planned level.