#[non_exhaustive]pub enum WaveStatus {
Draft,
Released,
InProgress,
Completed,
Cancelled,
}Expand description
Status of a wave.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Draft
Wave is being configured; orders have not been released to the floor.
Released
Wave has been released and pick tasks are available to workers.
InProgress
Picking is underway; at least one pick task has been started.
Completed
All pick tasks in the wave have been completed.
Cancelled
Wave was cancelled before all picks were completed.