#[non_exhaustive]pub enum WriteOffReason {
Uncollectible,
Bankruptcy,
CustomerDispute,
SmallBalance,
AccountClosed,
Deceased,
Other,
}Expand description
Write-off reason code
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Uncollectible
Debt is deemed uncollectible after exhausting collection efforts.
Bankruptcy
Customer has filed for bankruptcy protection.
CustomerDispute
Balance is disputed and resolution favoured the customer.
SmallBalance
Balance is too small to justify further collection costs.
AccountClosed
Customer account has been closed.
Deceased
Customer is deceased and the estate cannot cover the balance.
Other
Write-off reason not covered by other variants.