pub struct ActivityLogs { /* private fields */ }Expand description
Activity log operations.
Implementations
Sourceimpl ActivityLogs
impl ActivityLogs
Sourcepub fn is_supported(&self) -> bool
pub fn is_supported(&self) -> bool
Whether activity logs are supported by the active backend.
Sourcepub fn record(&self, input: RecordActivity) -> Result<ActivityLogEntry>
pub fn record(&self, input: RecordActivity) -> Result<ActivityLogEntry>
Record a new activity log entry.
Sourcepub fn get(&self, id: ActivityLogId) -> Result<Option<ActivityLogEntry>>
pub fn get(&self, id: ActivityLogId) -> Result<Option<ActivityLogEntry>>
Get an entry by ID.
Sourcepub fn list(&self, filter: ActivityLogFilter) -> Result<Vec<ActivityLogEntry>>
pub fn list(&self, filter: ActivityLogFilter) -> Result<Vec<ActivityLogEntry>>
List entries with filter (most recent first).
Sourcepub fn history_for_subject(
&self,
subject_type: &str,
subject_id: Uuid,
) -> Result<Vec<ActivityLogEntry>>
pub fn history_for_subject( &self, subject_type: &str, subject_id: Uuid, ) -> Result<Vec<ActivityLogEntry>>
List the full history for a single subject, most recent first.