CommerceBuilder

Struct CommerceBuilder 

pub struct CommerceBuilder { /* private fields */ }
Builder for creating a Commerce instance with custom configuration.

Implementations

Source

impl CommerceBuilder

pub fn new() -> Self

Create a new builder with default settings.

pub fn sqlite(self, path: &str) -> Self

Available on crate feature sqlite only.

Set the SQLite database path.

pub fn database(self, path: &str) -> Self

Available on crate feature sqlite only.

Set the database path (alias for sqlite).

pub fn in_memory(self) -> Self

Available on crate feature sqlite only.

Configure for in-memory SQLite database.

pub const fn max_connections(self, count: u32) -> Self

Set the maximum number of database connections.

pub const fn metrics_config(self, config: MetricsConfig) -> Self

Configure in-process engine metrics collection.

pub const fn disable_metrics(self) -> Self

Disable in-process engine metrics collection.

pub fn event_config(self, config: EventConfig) -> Self

Available on crate feature events only.

Configure the event system.

Example
use stateset_embedded::{Commerce, EventConfig};

let commerce = Commerce::builder()
    .database(":memory:")
    .event_config(EventConfig {
        channel_capacity: 2048,
        enable_webhooks: true,
        ..Default::default()
    })
    .build()?;
pub fn build_with_defaults(self) -> Result<Commerce, CommerceError>

Available on crate feature sqlite only.

Build with sensible defaults for development/testing.

Creates an in-memory SQLite database with default settings. This is the quickest way to get started for testing.

Example
use stateset_embedded::Commerce;

let commerce = Commerce::builder().build_with_defaults()?;
// Equivalent to Commerce::in_memory()
pub fn build(self) -> Result<Commerce, CommerceError>

Build the Commerce instance.