pub struct CreateProduct {
pub name: String,
pub slug: Option<String>,
pub description: Option<String>,
pub product_type: Option<ProductType>,
pub attributes: Option<Vec<ProductAttribute>>,
pub seo: Option<SeoMetadata>,
pub variants: Option<Vec<CreateProductVariant>>,
}Expand description
Input for creating a product
Fields
name: Stringslug: Option<String>description: Option<String>product_type: Option<ProductType>attributes: Option<Vec<ProductAttribute>>seo: Option<SeoMetadata>variants: Option<Vec<CreateProductVariant>>Trait Implementations
Sourceimpl Clone for CreateProduct
impl Clone for CreateProduct
Sourcefn clone(&self) -> CreateProduct
fn clone(&self) -> CreateProduct
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateProduct
impl Debug for CreateProduct
Sourceimpl Default for CreateProduct
impl Default for CreateProduct
Sourcefn default() -> CreateProduct
fn default() -> CreateProduct
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CreateProduct
impl<'de> Deserialize<'de> for CreateProduct
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<CreateProduct, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<CreateProduct, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for CreateProduct
impl Serialize for CreateProduct
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl Validate for CreateProduct
impl Validate for CreateProduct
Sourcefn validate(&self) -> Result<(), CommerceError>
fn validate(&self) -> Result<(), CommerceError>
Validate a product create request.
Requires a non-empty product name and validates each supplied variant (valid SKU, non-negative price/cost). A product may be created without variants, which are commonly added afterward.