pub struct OrderItem {
pub id: OrderItemId,
pub order_id: OrderId,
pub product_id: ProductId,
pub variant_id: Option<Uuid>,
pub sku: String,
pub name: String,
pub quantity: i32,
pub unit_price: Decimal,
pub discount: Decimal,
pub tax_amount: Decimal,
pub total: Decimal,
}Expand description
Order line item
Fields
id: OrderItemIdorder_id: OrderIdproduct_id: ProductIdvariant_id: Option<Uuid>sku: Stringname: Stringquantity: i32unit_price: Decimaldiscount: Decimaltax_amount: Decimaltotal: DecimalImplementations
Sourceimpl OrderItem
impl OrderItem
Sourcepub fn calculate_total(
quantity: i32,
unit_price: Decimal,
discount: Decimal,
tax: Decimal,
) -> Decimal
pub fn calculate_total( quantity: i32, unit_price: Decimal, discount: Decimal, tax: Decimal, ) -> Decimal
Calculate a line item’s money total, rounded to the currency minor unit.
The result is rounded to MONEY_SCALE (2) decimal places so the stored
line total is a real money amount and an order’s total_amount (the sum
of these line totals) foots exactly to its line items. All order-creation
paths on both backends route through this function so they agree to the
cent.