pub struct PrintStations { /* private fields */ }Expand description
Print station operations.
Implementations
Sourceimpl PrintStations
impl PrintStations
Sourcepub fn is_supported(&self) -> bool
pub fn is_supported(&self) -> bool
Whether print stations are supported by the active backend.
Sourcepub fn pair(&self, input: CreatePrintStation) -> Result<PairStationResult>
pub fn pair(&self, input: CreatePrintStation) -> Result<PairStationResult>
Pair a new print station, returning the one-time token.
Sourcepub fn list_stations(&self) -> Result<Vec<PrintStation>>
pub fn list_stations(&self) -> Result<Vec<PrintStation>>
List paired stations.
Sourcepub fn get_station(&self, id: PrintStationId) -> Result<Option<PrintStation>>
pub fn get_station(&self, id: PrintStationId) -> Result<Option<PrintStation>>
Get a station by ID.
Sourcepub fn revoke_station(&self, id: PrintStationId) -> Result<PrintStation>
pub fn revoke_station(&self, id: PrintStationId) -> Result<PrintStation>
Revoke a station.
Sourcepub fn enqueue_job(
&self,
station_id: PrintStationId,
input: EnqueuePrintJob,
) -> Result<PrintJob>
pub fn enqueue_job( &self, station_id: PrintStationId, input: EnqueuePrintJob, ) -> Result<PrintJob>
Enqueue a print job to a station.
Sourcepub fn next_job(&self, station_id: PrintStationId) -> Result<Option<PrintJob>>
pub fn next_job(&self, station_id: PrintStationId) -> Result<Option<PrintJob>>
Pick up the next queued job for a station.
Sourcepub fn complete_job(
&self,
job_id: PrintJobId,
success: bool,
) -> Result<PrintJob>
pub fn complete_job( &self, job_id: PrintJobId, success: bool, ) -> Result<PrintJob>
Mark a job printed or failed.
Sourcepub fn list_jobs(
&self,
station_id: PrintStationId,
filter: PrintJobFilter,
) -> Result<Vec<PrintJob>>
pub fn list_jobs( &self, station_id: PrintStationId, filter: PrintJobFilter, ) -> Result<Vec<PrintJob>>
List jobs for a station.